==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/amber/table/ForeignColumn.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.amber.table;

import com.caucho.util.L10N;

/**
 * Column linking to another table
 */
public class ForeignColumn extends Column {
  private static final L10N L = new L10N(ForeignColumn.class);

  private Column _targetColumn;
  
  /**
   * Creates a foreign column.
   *
   * @param table the owning table
   * @param name the column name
   * @param targetColumn the key column of the target table
   */
  ForeignColumn(Table table, String name, Column targetColumn)
  {
    super(table, name, targetColumn.getType());

    _targetColumn = targetColumn;

    if (! targetColumn.isPrimaryKey())
      throw new IllegalStateException(L.l("Foreign column '{0}' of table '{1}' must be a primary key.",
					  targetColumn.getName(),
					  targetColumn.getTable().getName()));
  }

  /**
   * Returns the target column.
   */
  public Column getTargetColumn()
  {
    return _targetColumn;
  }

  public String toString()
  {
    return "ForeignColumn[" + getName() + "," + _targetColumn + "]";
  }
}

==> resin-4.0.66-src.tar.gz: resin-4.0.66/modules/resin/src/com/caucho/amber/table/ForeignColumn.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.amber.table;

import com.caucho.util.L10N;

/**
 * AmberColumn linking to another table
 */
public class ForeignColumn extends AmberColumn {
  private static final L10N L = new L10N(ForeignColumn.class);

  private AmberColumn _targetColumn;
  
  /**
   * Creates a foreign column.
   *
   * @param table the owning table
   * @param name the column name
   * @param targetColumn the key column of the target table
   */
  ForeignColumn(AmberTable table, String name, AmberColumn targetColumn)
  {
    super(table, name, targetColumn.getType());

    _targetColumn = targetColumn;

    if (! targetColumn.isPrimaryKey())
      throw new IllegalStateException(L.l("Foreign column '{0}' of table '{1}' must be a primary key.",
                                          targetColumn.getName(),
                                          targetColumn.getTable().getName()));
  }

  /**
   * Returns the target column.
   */
  public AmberColumn getTargetColumn()
  {
    return _targetColumn;
  }

  public String toString()
  {
    return "ForeignColumn[" + getName() + "," + _targetColumn + "]";
  }
}
